==> contrib-0.1.17.jar: project.clj <==
(defproject webnf.deps/contrib "0.1.17"
  :plugins [[lein-modules "0.3.11"]]
  :description "Depend on projects covered by clojure's CA"
  :dependencies [[org.clojure/algo.generic "0.1.2"]
                 [org.clojure/algo.monads "0.1.5"]
                 [com.google.code.findbugs/jsr305  "_"] ;; cljs
                 [org.clojure/clojurescript "_"]
                 [org.clojure/core.async "_"]
                 [org.clojure/core.cache "0.6.4"]
                 [org.clojure/core.contracts "0.0.5"]
                 [org.clojure/core.incubator "0.1.3"]
                 [org.clojure/core.logic "0.8.10"]
                 [org.clojure/core.match "0.3.0-alpha4"]
                 [org.clojure/core.memoize "0.5.7" :exclusions [org.clojure/core.cache]]
                 [org.clojure/core.rrb-vector "0.0.11"]
                 [org.clojure/core.typed "_" :classifier "slim"]
                 [org.clojure/core.unify "0.5.6"]
                 [org.clojure/data.avl "0.0.12"]
                 [org.clojure/data.codec "0.1.0"]
                 [org.clojure/data.csv "0.1.2"]
                 [org.clojure/data.finger-tree "0.0.2"]
                 [org.clojure/data.fressian "0.2.0"]
                 [org.clojure/data.generators "0.1.2"]
                 [org.clojure/data.int-map "0.2.0"]
                 [org.clojure/data.json "0.2.6"]
                 [org.clojure/data.priority-map "0.0.7"]
                 [org.clojure/data.xml "0.0.8"]
                 [org.clojure/data.zip "0.1.1"]
                 [org.clojure/java.classpath "0.2.2"]
                 [org.clojure/java.data "0.1.1"]
                 [org.clojure/java.jdbc "0.3.7"]
                 [org.clojure/java.jmx "0.3.1"]
                 [org.clojure/jvm.tools.analyzer "0.6.1"]
                 [org.clojure/math.combinatorics "0.1.1"]
                 [org.clojure/math.numeric-tower "0.0.4"]
                 [org.clojure/test.check "0.8.0-alpha3"]
                 [org.clojure/test.generative "0.5.2"]
                 [org.clojure/tools.analyzer "0.6.6"]
                 [org.clojure/tools.analyzer.js "0.1.0-beta5"]
                 [org.clojure/tools.analyzer.jvm "0.6.7"]
                 [org.clojure/tools.cli "0.3.1"]
                 [org.clojure/tools.emitter.jvm "0.1.0-beta5"]
                 [org.clojure/tools.logging "0.3.1"]
                 [org.clojure/tools.macro "0.1.5"]
                 [org.clojure/tools.namespace "0.2.10"]
                 [org.clojure/tools.nrepl "0.2.10"]
                 [org.clojure/tools.reader "_"]
                 [org.clojure/tools.trace "0.7.8"]])

==> contrib-0.1.18.jar: project.clj <==
(defproject webnf.deps/contrib "0.1.18"
  :plugins [[lein-modules "0.3.11"]]
  :description "Depend on projects covered by clojure's CA"
  :dependencies [[org.clojure/algo.generic "0.1.2"]
                 [org.clojure/algo.monads "0.1.5"]
                 [com.google.code.findbugs/jsr305  "_"] ;; cljs
                 [org.clojure/clojurescript "_"
                  :exclusions [org.clojure/tools.reader]]
                 [org.clojure/core.async "_"]
                 [org.clojure/core.cache "0.6.4"]
                 [org.clojure/core.contracts "0.0.5"]
                 [org.clojure/core.incubator "0.1.3"]
                 [org.clojure/core.logic "0.8.10"]
                 [org.clojure/core.match "0.3.0-alpha4"]
                 [org.clojure/core.memoize "0.5.7" :exclusions [org.clojure/core.cache]]
                 [org.clojure/core.rrb-vector "0.0.11"]
                 [org.clojure/core.typed "_" :classifier "slim"]
                 [org.clojure/core.unify "0.5.6"]
                 [org.clojure/data.avl "0.0.12"]
                 [org.clojure/data.codec "0.1.0"]
                 [org.clojure/data.csv "0.1.2"]
                 [org.clojure/data.finger-tree "0.0.2"]
                 [org.clojure/data.fressian "0.2.0"]
                 [org.clojure/data.generators "0.1.2"]
                 [org.clojure/data.int-map "0.2.0"]
                 [org.clojure/data.json "0.2.6"]
                 [org.clojure/data.priority-map "0.0.7"]
                 [org.clojure/data.xml "0.0.8"]
                 [org.clojure/data.zip "0.1.1"]
                 [org.clojure/java.classpath "0.2.2"]
                 [org.clojure/java.data "0.1.1"]
                 [org.clojure/java.jdbc "0.3.7"]
                 [org.clojure/java.jmx "0.3.1"]
                 [org.clojure/jvm.tools.analyzer "0.6.1"]
                 [org.clojure/math.combinatorics "0.1.1"]
                 [org.clojure/math.numeric-tower "0.0.4"]
                 [org.clojure/test.check "0.8.0-alpha3"]
                 [org.clojure/test.generative "0.5.2"]
                 [org.clojure/tools.analyzer "0.6.6"]
                 [org.clojure/tools.analyzer.js "0.1.0-beta5"]
                 [org.clojure/tools.analyzer.jvm "0.6.7"]
                 [org.clojure/tools.cli "0.3.1"]
                 [org.clojure/tools.emitter.jvm "0.1.0-beta5"]
                 [org.clojure/tools.logging "0.3.1"]
                 [org.clojure/tools.macro "0.1.5"]
                 [org.clojure/tools.namespace "0.2.10"]
                 [org.clojure/tools.nrepl "_"]
                 [org.clojure/tools.reader "_"]
                 [org.clojure/tools.trace "0.7.8"]])
